import { LITChain, LITCosmosChain, LITEVMChain, LITSVMChain } from '@litprotocol-dev/constants';
/**
 * Lit Protocol Network Public Key
 */
export declare const NETWORK_PUB_KEY: string;
export declare const LIT_AUTH_SIG_CHAIN_KEYS: Array<string>;
export declare const AUTH_SIGNATURE_BODY = "I am creating an account to use Lit Protocol at {{timestamp}}";
/**
 * EVM Chains supported by the LIT protocol.  Each chain includes an optional pre-deployed token contract that you may use for minting LITs.  These are ERC1155 contracts that let you mint any quantity of a given token.  Use the chain name as a key in this object.
 * @constant
 * @type { LITEVMChain }
 * @default
 */
export declare const LIT_CHAINS: LITChain<LITEVMChain>;
export declare const LIT_EVM_CHAINS: LITChain<LITEVMChain>;
/**
 * Solana Chains supported by the LIT protocol.  Use the chain name as a key in this object.
 * @constant
 * @type { LITSVMChain }
 * @default
 */
export declare const LIT_SVM_CHAINS: LITChain<LITSVMChain>;
/**
 * Cosmos Chains supported by the LIT protocol.  Use the chain name as a key in this object.
 * @constant
 * @type { LITCosmosChain }
 * @default
 */
export declare const LIT_COSMOS_CHAINS: LITChain<LITCosmosChain>;
/**
 * All Chains supported by the LIT protocol.  Use the chain name as a key in this object.
 * @type { LITChain<LITEVMChain | LITSVMChain | LITCosmosChain> }
 */
export declare const ALL_LIT_CHAINS: LITChain<LITEVMChain | LITSVMChain | LITCosmosChain>;
/**
 * Local storage key constants
 */
export declare const LOCAL_STORAGE_KEYS: {
    AUTH_COSMOS_SIGNATURE: string;
    WALLET_CONNECT: string;
    AUTH_SIGNATURE: string;
    AUTH_SOL_SIGNATURE: string;
    WEB3_PROVIDER: string;
    KEY_PAIR: string;
};
/**
 * Symmetric key algorithm parameters
 */
export declare const SYMM_KEY_ALGO_PARAMS: {
    name: string;
    length: number;
};
/**
 *
 * ALL LIT NETWORKS
 *
 */
export declare const LIT_NETWORKS: {
    jalapeno: string[];
    serrano: string[];
    localhost: string[];
    custom: any[];
};
