import { AccsCOSMOSParams, AccsDefaultParams, AccsEVMParams, AccsOperatorParams, AccsRegularParams, AccsSOLV2Params, ConditionItem, ILitError, JsonSigningResourceId } from '@litprotocol-dev/constants';
/**
 *
 * Canonical Unified Access Control Condition Formatter
 *
 * @param { ConditionItem } cond
 * @returns { any[] | AccsOperatorParams | any }
 */
export declare const canonicalUnifiedAccessControlConditionFormatter: (cond: ConditionItem) => AccsOperatorParams | any;
/**
 *
 * (SOLANA) Canonical Solana RPC Condition Formatter
 *
 * need to return in the exact format below:
 * but make sure we don't include the optional fields:
   ---
    #[derive(Debug, Serialize, Deserialize, Clone)]
    #[serde(rename_all = "camelCase")]
    pub struct SolRpcCondition {
        pub method: String,
        pub params: Vec<serde_json::Value>,
        pub pda_params: Option<Vec<serde_json::Value>>,
        pub pda_interface: Option<SolPdaInterface>,
        pub chain: String,
        pub return_value_test: JsonReturnValueTestV2,
    }

    #[derive(Debug, Serialize, Deserialize, Clone)]
    #[serde(rename_all = "camelCase")]
    pub struct SolPdaInterface {
        pub offset: u64,
        pub fields: serde_json::Value,
    }
    ---
 *
 * @param { object } cond
 * @param { boolean } requireV2Conditions
 *
 * @returns { any[] | AccsOperatorParams | AccsRegularParams | AccsSOLV2Params | ILitError | any }
 */
export declare const canonicalSolRpcConditionFormatter: (cond: ConditionItem, requireV2Conditions?: boolean) => any[] | AccsOperatorParams | AccsRegularParams | AccsSOLV2Params | ILitError | any;
/**
 *
 * (DEFAULT) Canonical Access Control Condition Formatter
 *
 * need to return in the exact format below:
   ---
    pub struct JsonAccessControlCondition {
      pub contract_address: String,
      pub chain: String,
      pub standard_contract_type: String,
      pub method: String,
      pub parameters: Vec<String>,
      pub return_value_test: JsonReturnValueTest,
    }
    ---
 *
 * @param { object } cond
 *
 * @returns { any[] | AccsOperatorParams | AccsDefaultParams | any }
 */
export declare const canonicalAccessControlConditionFormatter: (cond: ConditionItem) => any[] | AccsOperatorParams | AccsDefaultParams | any;
/**
 *
 * (EVM) Canonical EVM Contract Condition Formatter
 *
 *  need to return in the exact format below:
    ---
    pub struct JsonAccessControlCondition {
        pub contract_address: String,
        pub chain: String,
        pub standard_contract_type: String,
        pub method: String,
        pub parameters: Vec<String>,
        pub return_value_test: JsonReturnValueTest,
    }
    ---
 *
 * @param { ConditionItem } cond
 *
 * @returns
 */
export declare const canonicalEVMContractConditionFormatter: (cond: ConditionItem) => any[] | AccsOperatorParams | AccsEVMParams | any;
/**
 *
 * (COSMOS) Canonical Condition Formmater for Cosmos
 *
 * need to return in the exact format below:
   ---
    pub struct CosmosCondition {
        pub path: String,
        pub chain: String,
        pub return_value_test: JsonReturnValueTestV2,
    }
   ---
 *
 *
 * @param { ConditionItem } cond
 * @returns
 */
export declare const canonicalCosmosConditionFormatter: (cond: ConditionItem) => any[] | AccsOperatorParams | AccsCOSMOSParams | any;
/**
 *
 * Canonical ResourceId Formatter returning JSON signing resource id
 *
 * @param { JsonSigningResourceId } resId
 *
 * @returns { JsonSigningResourceId }
 *
 */
export declare const canonicalResourceIdFormatter: (resId: JsonSigningResourceId) => JsonSigningResourceId;
