import { AccessControlConditions, EvmContractConditions, JsonSigningResourceId, SolRpcConditions, UnifiedAccessControlConditions } from '@litprotocol-dev/constants';
/**
 *
 * Hash the unified access control conditions using SHA-256 in a deterministic way.
 *
 * @param { UnifiedAccessControlConditions } unifiedAccessControlConditions - The unified access control conditions to hash.
 * @returns { Promise<ArrayBuffer> } A promise that resolves to an ArrayBuffer that contains the hash
 */
export declare const hashUnifiedAccessControlConditions: (unifiedAccessControlConditions: UnifiedAccessControlConditions) => Promise<ArrayBuffer>;
/**
 *
 * Hash resource id
 *
 * @param { JsonSigningResourceId } resourceId
 *
 * @returns { Promise<ArrayBuffer> }
 *
 */
export declare const hashResourceId: (resourceId: JsonSigningResourceId) => Promise<ArrayBuffer>;
/**
 *
 * Hash access control conditions
 *
 * @param { AccessControlConditions } accessControlConditions
 *
 * @returns { Promise<ArrayBuffer> }
 *
 */
export declare const hashAccessControlConditions: (accessControlConditions: AccessControlConditions) => Promise<ArrayBuffer>;
/**
 *
 * Hash EVM access control conditions
 *
 * @param { EvmContractConditions } evmContractConditions
 *
 * @returns { Promise<ArrayBuffer> }
 *
 */
export declare const hashEVMContractConditions: (evmContractConditions: EvmContractConditions) => Promise<ArrayBuffer>;
/**
 *
 * Hash SOL access control conditions
 *
 * @param { SolRpcConditions } solRpcConditions
 *
 * @returns { Promise<ArrayBuffer> }
 *
 */
export declare const hashSolRpcConditions: (solRpcConditions: SolRpcConditions) => Promise<ArrayBuffer>;
