import { AccsCOSMOSParams, AccsDefaultParams, AccsEVMParams, AccsRegularParams, AccsSOLV2Params } from '@litprotocol-dev/constants';
/**
 *
 * Comparator translator
 *
 * @param { string } comparator
 *
 * @returns { string } humanized version of the comparator
 */
export declare const humanizeComparator: (comparator: string) => string | undefined;
/**
 *
 * Humanize EVM basic access control conditions
 *
 * @property { Array<AccsRegularParams | AccsDefaultParams | any> } accessControlConditions
 * @property { Array<any | string> } tokenList
 * @property { string } myWalletAddress
 *
 * @returns
 */
export declare const humanizeEvmBasicAccessControlConditions: ({ accessControlConditions, tokenList, myWalletAddress, }: {
    accessControlConditions: Array<AccsRegularParams | AccsDefaultParams | any>;
    tokenList?: any[] | undefined;
    myWalletAddress?: string | undefined;
}) => Promise<string>;
/**
 *
 * Humanize EVM contract conditions
 *
 * @property { Array<AccsEVMParams> } evmContractConditions
 * @property { Array<any | string> } tokenList
 * @property { string } myWalletAddress
 *
 * @returns { Promise<string> } A promise containing a human readable description of the access control conditions
 *
 */
export declare const humanizeEvmContractConditions: ({ evmContractConditions, tokenList, myWalletAddress, }: {
    evmContractConditions: Array<AccsEVMParams>;
    tokenList?: any[] | undefined;
    myWalletAddress?: string | undefined;
}) => Promise<string>;
/**
 *
 * Humanize SOL RPC Conditions
 *
 * @property { Array<AccsSOLV2Params> } solRpcConditions
 * @property { Array<any | string> } tokenList
 * @property { string } myWalletAddress
 *
 * @returns { Promise<string> } A promise containing a human readable description of the access control conditions
 *
 */
export declare const humanizeSolRpcConditions: ({ solRpcConditions, tokenList, myWalletAddress, }: {
    solRpcConditions: Array<AccsSOLV2Params>;
    tokenList?: any[] | undefined;
    myWalletAddress?: string | undefined;
}) => Promise<string>;
/**
 *
 * Humanize Cosmos Conditions
 *
 * @property { Array<AccsCOSMOSParams> } cosmosConditions
 * @property { Array<any | string> } tokenList
 * @property { string } myWalletAddress
 *
 * @returns { Promise<string> } A promise containing a human readable description of the access control conditions
 *
 */
export declare const humanizeCosmosConditions: ({ cosmosConditions, tokenList, myWalletAddress, }: {
    cosmosConditions: Array<AccsCOSMOSParams | any>;
    tokenList?: any[] | undefined;
    myWalletAddress?: string | undefined;
}) => Promise<string>;
/**
 *
 * Humanize unified access control conditions
 *
 * @property { Array<AccsRegularParams | AccsDefaultParams | AccsSOLV2Params | AccsEVMParams | AccsCOSMOSParams> } unifiedAccessControlConditions
 * @property { Array<any | string> } tokenList
 * @property { string } myWalletAddress
 *
 * @returns { Promise<string> } A promise containing a human readable description of the access control conditions
 */
export declare const humanizeUnifiedAccessControlConditions: ({ unifiedAccessControlConditions, tokenList, myWalletAddress, }: {
    unifiedAccessControlConditions: Array<AccsRegularParams | AccsDefaultParams | AccsSOLV2Params | AccsEVMParams | AccsCOSMOSParams>;
    tokenList?: any[] | undefined;
    myWalletAddress?: string | undefined;
}) => Promise<string>;
